user_current_list_repos: List the repos that the authenticated user owns or has access...

Description Usage Arguments Value Examples

Description

List the repos that the authenticated user owns or has access to

Usage

1
2
user_current_list_repos(api_endpoint = Sys.getenv("GITEA_BASE_URL"),
  gitea_token = Sys.getenv("GITEA_PAT"))

Arguments

api_endpoint

URL prefix for your gitea server (no trailing '/')

gitea_token

NOTE: we use access_token in the package

Value

data frame

Examples

1
2
3
4
## Not run: 
user_current_list_repos()

## End(Not run)

hrbrmstr/crumpets documentation built on May 4, 2019, 8:40 a.m.